# file: $WE2/we2_similar_pic.py
# 
# This python script loads a group of images and compares each image to a
# designated image and decides which image is more similar to the other through 
# comparison of their mean-square error
#
# Usage: 
#  python we2_similar_pic.py image_directory/ reference_img.jpg
#

# import some tools that we will need to accomplish this task
#
import matplotlib.pyplot as plt         # a plotting library
import numpy as np                      # a math library
import cv2                              # a C++ library
import os                               # an operative system library
import operator                         # a library for operations
import sys 								# a system library

###############################################################################
#
# the main program starts here
#
###############################################################################

# get the arguments, which is the directory where your images are saved and the
# image that you will be using as a reference
#
image_dir_a = sys.argv[1]
image_ref_a = sys.argv[2]

# initialize arrays that will contain the image data and the mean-square error 
# for each image.
#
data=[];
mse_pic=[];

# function: mse
# arguments:
#  imageA_a_a: first image to be compared (input)
#  imageB_a_a: second image to be compared (input)
# return:
#  err: mean-square error (output)  
# description: calculates the mean-square error between two images
#
def mse(imageA_a, imageB_a):
    
	# the mean-squared error between the two images is the
    # sum of the squared difference between the two images;
	#
    # NOTE: the two images must have the same dimension
	#
    err = np.sum((imageA_a.astype("float") - imageB_a.astype("float")) ** 2)
    err /= float(imageA_a.shape[0] * imageA_a.shape[1])
    
    # return the MSE, the lower the error, the more "similar"
    # the two images are
	#
    return err


# loop through all of the images in the specified directory and save them in
# a variable
#	
for filename in os.listdir(image_dir_a):
    data.append(filename)
	
# read the reference image and transform into the gray scale
#	
original = cv2.imread(image_ref_a)
original = cv2.cvtColor(original, cv2.COLOR_BGR2GRAY)

# iterate through all the images in the directory and compare them to the 
# reference image
#
for i in xrange(0,len(data)):

	# read images in the directory and convert them to the gray scale
	# 
	...
	# calculate the MSE of indexed image and reference image
	#
	...
	# if MSE=0 enter a very large number to prevent the selection of the same 
	# picture as the most similar
	# MSE values are saved in a list  
	#
     ...
		
	# display the MSE values in the console
	#
    print('MSE %s: %f' %(data[i], m))

# obtain the minimum MSE in the list and its respective index
#	
...

# print information to the console
#
print('The most similar image is %s' %(data[index]))

# show first image
#
fig = plt.figure("These are the most similar images")
ax = fig.add_subplot(1, 2, 1)
plt.imshow(original, cmap = plt.cm.gray)
plt.axis("off")


# show the second image
#
original2 = cv2.imread(image_dir_a+ data[index])
original2 = cv2.cvtColor(original2, cv2.COLOR_BGR2GRAY)
ax = fig.add_subplot(1, 2, 2)
plt.imshow(original2, cmap = plt.cm.gray)
plt.axis("off")

# show the images
#
plt.show()

###############################################################################
#
# the main program ends here
#
###############################################################################
